package routers
import "github.com/getkin/kin-openapi/routers"
Index ¶
Variables ¶
var ErrMethodNotAllowed error = &RouteError{"method not allowed"}
ErrMethodNotAllowed is returned when no method of the matched route matches
var ErrPathNotFound error = &RouteError{"no matching operation was found"}
ErrPathNotFound is returned when no route match is found
Types ¶
type Route ¶
type Route struct {
Spec *openapi3.T
Server *openapi3.Server
Path string
PathItem *openapi3.PathItem
Method string
Operation *openapi3.Operation
}
Route describes the operation an http.Request can match
type RouteError ¶
type RouteError struct {
Reason string
}
RouteError describes Router errors
func (*RouteError) Error ¶
func (e *RouteError) Error() string
type Router ¶
type Router interface {
// FindRoute matches an HTTP request with the operation it resolves to.
// Hosts are matched from the OpenAPIv3 servers key.
//
// If you experience ErrPathNotFound and have localhost hosts specified as your servers,
// turning these server URLs as relative (leaving only the path) should resolve this.
//
// See openapi3filter for example uses with request and response validation.
FindRoute(req *http.Request) (route *Route, pathParams map[string]string, err error)
}
Router helps link http.Request.s and an OpenAPIv3 spec
Source Files ¶
Directories ¶
| Path | Synopsis |
|---|---|
| routers/gorillamux | Package gorillamux implements a router. |
| routers/legacy | Package legacy implements a router. |
| routers/legacy/pathpattern | Package pathpattern implements path matching. |
- Version
- v0.132.0 (latest)
- Published
- Apr 29, 2025
- Platform
- linux/amd64
- Imports
- 2 packages
- Last checked
- 9 months ago –
Tools for package owners.